# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-01-30 13:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('telegrambot', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Bot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=200, null=True, verbose_name='Name')),
                ('token', models.CharField(db_index=True, max_length=100, verbose_name='Token')),
                ('ssl_certificate', models.FileField(blank=True, null=True, upload_to=b'telegrambot/ssl/', verbose_name='SSL certificate')),
                ('enabled', models.BooleanField(default=True, verbose_name='Enable')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name=b'Date Created')),
                ('modified', models.DateTimeField(auto_now=True, verbose_name='Date Modified')),
            ],
            options={
                'verbose_name': 'Bot',
                'verbose_name_plural': 'Bots',
            },
        ),
    ]
